summaryrefslogtreecommitdiff
path: root/drivers/gpu
diff options
context:
space:
mode:
authorHarshdeep Dhatt <hdhatt@codeaurora.org>2016-08-29 15:46:19 -0600
committerHarshdeep Dhatt <hdhatt@codeaurora.org>2016-10-05 11:38:37 -0600
commita694afed7b06eccc1adce71395ae706648f50eb5 (patch)
treeaa73e4a5018faaabebcdd3e972d1ff48d828b919 /drivers/gpu
parenteac51723e61ecd836a7dc5d60c717d980fc8fefe (diff)
msm: kgsl: Disable workaround on A540v2
Currently we have a workaround for A540 which inserts WFI after every direct-render 3D mode and every 2D mode draw. Add a check to enable this only on A540v1 as this workaround is not required for A540v2. CRs-Fixed: 1072767 Change-Id: I679bbf68ee3dcc1aee30d56a646a42b6ff09fb6f Signed-off-by: Harshdeep Dhatt <hdhatt@codeaurora.org>
Diffstat (limited to 'drivers/gpu')
-rw-r--r--drivers/gpu/msm/adreno_a5xx.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/drivers/gpu/msm/adreno_a5xx.c b/drivers/gpu/msm/adreno_a5xx.c
index 583de85678fc..1ad96f9b1612 100644
--- a/drivers/gpu/msm/adreno_a5xx.c
+++ b/drivers/gpu/msm/adreno_a5xx.c
@@ -2127,9 +2127,11 @@ static int _me_init_ucode_workarounds(struct adreno_device *adreno_dev)
case ADRENO_REV_A540:
/*
* WFI after every direct-render 3D mode draw and
* WFI after every 2D Mode 3 draw.
*/
- return 0x0000000A;
+ if (adreno_is_a540v1(adreno_dev))
+ return 0x0000000A;
default:
return 0x00000000; /* No ucode workarounds enabled */
}
@@ -2127,9 +2127,11 @@ static int _me_init_ucode_workarounds(struct adreno_device *adreno_dev)
/*
* WFI after every direct-render 3D mode draw and
- * WFI after every 2D Mode 3 draw.
+ * WFI after every 2D Mode 3 draw. This is needed
+ * only on a540v1.
*/